/*
 * (C) Alvaro Corts Cabrera. <alvarocortesc@gmail.com>
 * 
 * AuthLevel.cs 
 * 
 * Controla los niveles de autorizacin de acciones segn la base de datos.
 */

using System;
using MySql.Data.MySqlClient;

namespace FormulacionMagistral
{
	/// <summary>
	/// Description of AuthLevel.
	/// </summary>
	public class AuthLevel
	{
		private	MySqlConnection conexion;
     	private string cadenaConexion;

     	/// <summary>
		/// Constructor de la clase
		/// </summary>
		public AuthLevel()
		{
		}
		
		
		#region Asignadores de propiedades

		/// <summary>
		/// Asigna lo parametros de conexion con la base de datos
		/// para la autentificacion de usuario.
		/// </summary>
		/// <param name="host">Nombre o IP del servidor</param>
		/// <param name="port">Puerto de conexion</param> 
		/// <param name="user">Usuario de la BD</param>
		/// <param name="passwd">Password para el usuario</param>
		/// <param name="database">Base de datos del servidor</param>
		/// <returns>Devuelve nada.</returns>
		public void setConnectionParameters(string host, string port, string user, string passwd, string database){
		cadenaConexion = "server="+host+";port="+ port +";user id="+user+";password="+passwd + ";database="+database+";pooling=false";
		}

		#endregion
		
		
		#region Mtodo publicos

		/// <summary>
		/// Establece la conexion con la base de datos segun los 
		/// parametros asignados.
		/// </summary>
		/// <returns>Devuelve true si no hay error o false si existe algun problema</returns>
		private bool conectar(){
			try{
			conexion = new MySqlConnection(cadenaConexion);
			conexion.Open();
			return true;
			}catch(Exception e){
			FM_Errores.MostrarError("conectar","No se puede establecer la conexion con la base de datos",e);
			return false;
			}
		}

		/// <summary>
		/// Desconecta del servidor
		/// </summary>

		private void desconectar(){
			conexion.Close();
		}

		
		/// <summary>
		/// Devuelve el valor minimo de autorizacion para la accin solicitada
		/// </summary>
		/// <param name="actionid">ID de la accin</param>
		/// <returns>Devuelve un entero con el nivel mnimo</returns>
		public int get_level(int actionid){
			
			MySqlCommand MyCmd;
			MySqlDataReader MyLector;
			int nivelt = -1;
		
			try{
		
				if( this.conectar() )
				{
					MyCmd = new MySqlCommand("SELECT * FROM levels WHERE ActionID = '" + actionid.ToString() +"'",conexion);
					MyLector = MyCmd.ExecuteReader();
				while( MyLector.Read() )
				{
					 nivelt = MyLector.GetInt32(1); // Nivel de autorizacion
				}
					this.desconectar();
					return nivelt;
				}else{
					return nivelt;
				}
			}catch(MySqlException e){
				FM_Errores.MostrarError("AuthLevel","Error relacionado con la base de datos",e);
				return nivelt;
			}catch(Exception err){
				FM_Errores.MostrarError("AuthLevel","Error obteniendo nivel de autorizacion",err);
				return nivelt;
			}

		}
		
		
		#endregion
		
	}
	
}
