/*
 * 
 * Materia_rutinas.cs
 * 
 * (C) Alvaro Cortes. 2007. alvarocortesc@gmail.com
 * 
 * 
 * 
 * Algunas cosas para usar en MainForm.
 * 
 */

using System;
using System.Data;
using MySql.Data.MySqlClient;
using System.Collections;

namespace FormulacionMagistral
{
	/// <summary>
	/// Description of Materia_rutinas.
	/// </summary>
	public class Materia_rutinas
	{
		/// <summary>
		/// Obtiene una lista de todas las materias primas
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <returns>string[] con los nombres de las materias primas</returns>
		public static string[] get_list_materias(string strconn){
		
		ArrayList materias = new ArrayList();
		MySqlCommand MyCmd;
		MySqlConnection conexion;
		MySqlDataReader MyLector;
		
		try{
			conexion = new MySqlConnection(strconn);
			conexion.Open();
		
				MyCmd = new MySqlCommand("SELECT * FROM materia ORDER BY MateriaID",conexion);
				MyLector = MyCmd.ExecuteReader();
			while( MyLector.Read() )
				materias.Add(MyLector.GetString(1));
		MyLector.Close();
		conexion.Close();
		return (string[])materias.ToArray(typeof(string));
		}catch(MySqlException e){
			FM_Errores.MostrarError("get_list_materias","Error relacionado con la base de datos",e);
			return (string[])materias.ToArray(typeof(string));
		}catch(Exception err){
			FM_Errores.MostrarError("get_list_materias","Error obteniendo lista de materias primas",err);
			return (string[])materias.ToArray(typeof(string));
		}
			
		}

		/// <summary>
		/// Obtiene una lista de los sinonimos de la materia prima
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <param name="materiaid">ID de la materia</param>
		/// <returns>string[] con los nombres de las materias primas</returns>
		public static string[] get_sinonimos(string strconn, string materiaid){
		
		ArrayList materias = new ArrayList();
		MySqlCommand MyCmd;
		MySqlConnection conexion;
		MySqlDataReader MyLector;
		
		try{
			conexion = new MySqlConnection(strconn);
			conexion.Open();
		
				MyCmd = new MySqlCommand("SELECT * FROM sinonimos WHERE MateriaID = "+ materiaid + ";",conexion);
				MyLector = MyCmd.ExecuteReader();
			while( MyLector.Read() )
				materias.Add(MyLector.GetString(1));
		MyLector.Close();
		conexion.Close();
		return (string[])materias.ToArray(typeof(string));
		}catch(MySqlException e){
			FM_Errores.MostrarError("get_sinonimos","Error relacionado con la base de datos",e);
			return (string[])materias.ToArray(typeof(string));
		}catch(Exception err){
			FM_Errores.MostrarError("get_sinonimos","Error obteniendo lista de sinonimos",err);
			return (string[])materias.ToArray(typeof(string));
		}
			
		}

		/// <summary>
		/// Asocia un nuevo sinonimo a la materia prima
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <param name="sinonimo">Nombre del sinonimo</param>
		/// <param name="materiaid">ID de la materia prima</param>
		/// <returns>Devuelve verdadero si ha tenido xito</returns>
		public static bool new_sinonimo(string strconn, string sinonimo, string materiaid){
		MySqlCommand MyCmd;
		MySqlConnection conexion;

		try{
		
		conexion = new MySqlConnection(strconn);
		conexion.Open();
		MyCmd = new MySqlCommand("INSERT INTO sinonimos (MateriaID,sinonimo) VALUES (" + materiaid +",'" + sinonimo + "');",conexion);
		MyCmd.ExecuteNonQuery();
		conexion.Close();
		return true;
		}catch(MySqlException e){
			FM_Errores.MostrarError("new_sinonimo","Error relacionado con la base de datos",e);
			return false;
		}catch(Exception err){
			FM_Errores.MostrarError("new_sinonimo","Error introduciendo un nuevo sinonimo",err);
			return false;
		}
		}

		/// <summary>
		/// Borra el sinonimo especificado
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <param name="sinonimo">Nombre del sinonimo</param>
		/// <param name="materiaid">ID de la materia prima asociada</param>
		/// <returns></returns>
		public static bool delete_sinonimo(string strconn, string sinonimo, string materiaid){

		MySqlCommand MyCmd;
		MySqlConnection conexion;

		try{
		
		conexion = new MySqlConnection(strconn);
		conexion.Open();
		MyCmd = new MySqlCommand("DELETE FROM sinonimos WHERE MateriaID = " + materiaid + " AND sinonimo = '" + sinonimo + "'",conexion);

		MyCmd.ExecuteNonQuery();
		conexion.Close();
			return true;

		}catch(MySqlException e){
			FM_Errores.MostrarError("delete_sinonimo","Error relacionado con la base de datos",e);
			return false;
		}catch(Exception err){
			FM_Errores.MostrarError("delete_sinonimo","Error borrando sinonimo",err);
			return false;
		}

		}
		
		
		/// <summary>
		/// Devuelve el id asociado al nombre de la materia
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <param name="nombre">Nombre de la materia</param>
		/// <returns>string[] con los nombres de las materias primas</returns>
		public static string get_materiaid(string strconn, string nombre){
		
		MySqlCommand MyCmd;
		MySqlConnection conexion;
		MySqlDataReader MyLector;
		int materiaid = -1;
		
		try{
			conexion = new MySqlConnection(strconn);
			conexion.Open();
		
				MyCmd = new MySqlCommand("SELECT * FROM materia WHERE DOE = '"+ nombre + "';",conexion);
				MyLector = MyCmd.ExecuteReader();
			while( MyLector.Read() )
				materiaid = MyLector.GetInt32(0);
		MyLector.Close();
		conexion.Close();
		return materiaid.ToString();
		}catch(MySqlException e){
			FM_Errores.MostrarError("get_materiaid","Error relacionado con la base de datos",e);
		return materiaid.ToString();
		}catch(Exception err){
			FM_Errores.MostrarError("get_materiaid","Error obteniendo el identificador de la materia",err);
			return materiaid.ToString();
		}
			
		}
				

		/// <summary>
		/// Obtiene toda la informacion de la tabla especificaciones
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <param name="materiaid">ID de la materia</param>
		/// <returns>string[] con los campos de la tabla</returns>
		public static string[] get_especificaciones(string strconn, string materiaid){
		
		ArrayList materias = new ArrayList();
		MySqlCommand MyCmd;
		MySqlConnection conexion;
		MySqlDataReader MyLector;
		
		try{
			conexion = new MySqlConnection(strconn);
			conexion.Open();
		
				MyCmd = new MySqlCommand("SELECT * FROM especificaciones WHERE MateriaID = "+ materiaid + ";",conexion);
				MyLector = MyCmd.ExecuteReader();
				if( MyLector.Read() )
				{
					materias.Add( MyLector.GetInt32(1).ToString() ); // UnidadID
					for(int i=2; i<= 9 ; ++i)
					materias.Add(MyLector.GetString(i)); // Campos de texto
					materias.Add(MyLector.GetFloat(10).ToString()); // Precio
				}
		MyLector.Close();
		conexion.Close();
		return (string[])materias.ToArray(typeof(string));
		}catch(MySqlException e){
			FM_Errores.MostrarError("get_especificaciones","Error relacionado con la base de datos",e);
			return (string[])materias.ToArray(typeof(string));
		}catch(Exception err){
			FM_Errores.MostrarError("get_especificaciones","Error obteniendo especificaciones",err);
			return (string[])materias.ToArray(typeof(string));
		}
			
		}
		

		/// <summary>
		/// Obtiene el nombre de la unidad de medida
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <param name="unidadid">ID de la unidad de medida</param>
		/// <returns>Devuelve el nombre de la unidad de medida</returns>
		public static string get_unidad(string strconn, string unidadid){
		
		MySqlCommand MyCmd;
		MySqlConnection conexion;
		MySqlDataReader MyLector;
		string nombre = "";
		
		try{
			conexion = new MySqlConnection(strconn);
			conexion.Open();
		
				MyCmd = new MySqlCommand("SELECT * FROM unidades WHERE UnidadID = "+ unidadid + ";",conexion);
				MyLector = MyCmd.ExecuteReader();
			while( MyLector.Read() )
				nombre = MyLector.GetString(1);
		MyLector.Close();
		conexion.Close();
		return nombre;
		}catch(MySqlException e){
			FM_Errores.MostrarError("get_unidad","Error relacionado con la base de datos",e);
		return nombre;
		}catch(Exception err){
			FM_Errores.MostrarError("get_unidad","Error obteniendo el nombre asociado a la unidad de medida",err);
			return nombre;
		}
			
		}
		
		
		
	}
}
