/*
 *
 *	TestDBConnection.cs
 *
 *	(C) 2006. Alvaro Corts. <alvarocortesc@gmail.com>
 *
 *	Clase que comprueba la conexion MySQL con unos parametros especificados
 *	por el usuario.
 *
 */


using System;
using MySql.Data.MySqlClient;

namespace Formulacion{


class TestDBConnection{

	private string cadenaConexion;
	
#region Constructores de la clase.

	/// <summary>
	/// Constructor sin parametros
	/// </summary>
	public TestDBConnection(){}

	/// <summary>
	/// Constructor con parametros
	/// </summary>
	/// <param name="strConnection">Cadena de conexin</param>
	public TestDBConnection( string strConnection){
		cadenaConexion = strConnection;
	}

	/// <summary>
	/// Constructor con multiples parametros para construcciona cadena de conexion
	/// </summary>
	/// <param name="host">Nombre o IP</param>
	/// <param name="port">Puerto de conexion</param>
	/// <param name="user">Usuario</param>
	/// <param name="passwd">Contrasea del usuario</param>
	/// <param name="database">Nombre de la base de datos</param>
	public TestDBConnection( string host, string port ,string user, string passwd, string database){
		cadenaConexion = "host="+host+";port="+port+";use id="+user+";password="+passwd+"; database="+database+";pooling=false"; 
	}
#endregion
	
#region Asignaciones de valores de la conexion.

	/// <summary>
	/// Asigna un valor determinado por el usuario a la cadena 
	/// de conexion
	/// </summary>
	/// <param name="strConn">Cadena de conexion contruida por el usuario</param>
	public void setConnectionString( string strConn ){
		cadenaConexion =  strConn;
	}

	/// <summary>
	/// Asigna una serie de valores para construir la cadena de conexin
	/// </summary>
	/// <param name="host">Nombre o IP</param>
	/// <param name="port">Puerto de conexion</param>
	/// <param name="user">Usuario para conexin</param>
	/// <param name="passwd">Contrasea del usuario</param>
	/// <param name="database">Nombre de la base de datos a conectar</param>
	public void setConnectionParameters(string host,string port, string user, string passwd, string database){
	cadenaConexion = "host="+host+";port="+port+";user id="+user+";password="+passwd+";database="+database+";pooling = false";
	}

#endregion

#region Metodos de comprobacion de conexion

	/// <summary>
	/// Comprueba con los datos asignados si existe se puede
	/// establecer una conexin.
	/// </summary>
	/// <returns>Verdadero si se ha establecido una conexin</returns>
	public bool testConnection(){
		MySqlConnection conn = new MySqlConnection(cadenaConexion);
		try{
		conn.Open();
		conn.Close();
		return true;
		}catch(MySqlException err){
			System.Console.WriteLine("Error de conexion: " + err.Message);
			return false;
		}catch(Exception err){
			System.Console.WriteLine("Error Inespecifico: " + err.Message);
			return false;
		}
	}

#endregion

}


}
